@@ -7,14 +7,18 @@ sk1 <- read_key("../keys/id_ecdsa")
 pk1 <- read_pubkey("../keys/id_ecdsa.pub")
 
 test_that("reading protected keys", {
-  sk2 <- read_key("../keys/id_ecdsa.pw", password = "test")
+  if(fips_mode()){
+    expect_error(read_key("../keys/id_ecdsa.pw", password = "test"), "FIPS")
+  } else {
+    expect_error(read_key("../keys/id_ecdsa.pw", password = NULL), "bad")
+    sk2 <- read_key("../keys/id_ecdsa.pw", password = "test")
+    expect_equal(sk1, sk2)
+  }
   sk3 <- read_key("../keys/id_ecdsa.openssh")
   sk4 <- read_key("../keys/id_ecdsa.openssh.pw", password = "test")
 
-  expect_equal(sk1, sk2)
   expect_equal(sk1, sk3)
   expect_equal(sk1, sk4)
-  expect_error(read_key("../keys/id_ecdsa.pw", password = NULL), "bad")
 })
 
 test_that("reading public key formats", {
@@ -30,6 +34,7 @@ test_that("reading public key formats", {
 
 test_that("legacy pkcs1 format", {
   expect_equal(sk1, read_key(write_pkcs1(sk1)))
+  skip_if(fips_mode())
   expect_equal(sk1, read_key(write_pkcs1(sk1, password = 'test'), password = 'test'))
   #expect_equal(pk1, read_pubkey(write_pkcs1(pk1)))
   expect_error(read_key(write_pkcs1(sk1, password = 'test'), password = ''))
@@ -37,7 +42,7 @@ test_that("legacy pkcs1 format", {
 
 test_that("pubkey ssh fingerprint", {
   fp <- paste(as.list(pk1)$fingerprint, collapse = "")
-  expect_equal(fp, "100b0d5f53a36e63dc42085552cdc340")
+  expect_equal(fp, "53492762ee530db92cc0c651f4454803d474f3a5bef6cac301cc8f3aac5d7f9e")
   pk5 <- read_pubkey(readLines("../keys/authorized_keys")[3])
   expect_equal(pk1, pk5)
   pk6 <- read_pubkey(write_ssh(pk1))
